@@ -576,7 +576,11 @@ function azure_get_aks_credentials() {
     ## Login to azure to ensure using the expected account and subsciption from the bootstrap node.
     #azure_login
     # Get Azure kubernetes cluster credential
-    az aks get-credentials --overwrite-existing --resource-group "${RESOURCEGROUP_NAME}" --name "${CLOUD_CLUSTER_INSTANCE_NAME}" --admin
+    if [ "$mediafirst_integration" = false ]; then
+      az aks get-credentials --overwrite-existing --resource-group "${RESOURCEGROUP_NAME}" --name "${CLOUD_CLUSTER_INSTANCE_NAME}" --admin
+    else
+      az aks get-credentials --overwrite-existing --resource-group "${RESOURCEGROUP_NAME}" --name "${CLOUD_CLUSTER_INSTANCE_NAME}"
+    fi
     #if [[ "$(whoami)" != "root" ]] && [[ ! $RUN_AS_CONTAINER ]]; then
     #  mkdir -p ~/.kube
     #  sudo \cp /root/.kube/config ~/.kube/config
@@ -614,7 +618,7 @@ function set_aks_cluster_name() {
 
 function set_azure_resource_group() {
   legacy_rg_name="$CLUSTER_NAME-cms-resourcegroup"
-  new_rg_name="rg-$CLUSTER_NAME"
+  [ "$MEDIAFIRST_INTEGRATION" = false ] && new_rg_name="rg-$CLUSTER_NAME" || new_rg_name="${CLUSTER_NAME}_K8S"
 
   if grep -q "default[[:space:]]*= \"$legacy_rg_name\"" $TF_DEFAULT_VARIABLES; then
     # When using legacy resource groupname, it means the AKS cluster has been deployed
