@@ -80,7 +80,8 @@ function init_cms_k8s_resource() {
               --docker-server=$IMAGE_REGISTRY \
               --docker-username=$IMAGE_PULL_USER \
               --docker-password=$IMAGE_PULL_PASSWORD
-            kubectl patch serviceaccount default -n "$CMS_NAMESPACE" --type=merge -p "{\"imagePullSecrets\":[{\"name\":\"$IMAGE_PULL_SECRET_NAME\"}]}"          fi
+            kubectl patch serviceaccount default -n "$CMS_NAMESPACE" --type=merge -p "{\"imagePullSecrets\":[{\"name\":\"$IMAGE_PULL_SECRET_NAME\"}]}"          
+          fi
         fi
       fi
     fi
